@@ -307,7 +307,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         X_t = self._component_graph.compute_final_component_features(X, y=y)
         return X_t
 
-    def avm(self, X, batch_sample_sets=1, latest_production_version=1, max_sample_sz=15, min_sample_sz=5, conf_min=.68):
+    def avm(self, X, batch_sample_sets=1, latest_production_version=1, max_sample_sz=15, min_sample_sz=5, pred_interval=.68, conf_min=.5):
         """Main method for the BCI avm predictions. 
 
         Arguments:
@@ -327,6 +327,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         self.min_sample_sz = min_sample_sz
         self.batch_sample_sets = batch_sample_sets
         self.conf_min = conf_min
+        self.pred_interval = pred_interval
 
         if np.isnan(self.latest_production_version):
             self.latest_production_version = latest_production_version
@@ -471,7 +472,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
         stats = (np.array([y for y in y_preds_all]) - y_trus_all) / y_trus_all
         stats = np.nan_to_num(stats)
-        confs = [self.conf_min]
+        confs = [self.pred_interval]
         for alpha in confs:
             p = ((1.0 - alpha) / 2.0) * 100.0
             ylower = np.percentile(stats, p)
