@@ -140,7 +140,7 @@ def preprocess_data(data, drop_outlier=True, target='Price_p', test_size=0.15, s
         keep_cols.append('POSTCODE_OUTCODE')
         keep_cols.append('POSTCODE_AREA')
 
-    data = data[keep_cols]
+    data = data[[col for col in keep_cols if col in data.columns]]
 
     if 'POSTCODE_AREA' not in data.columns:
         try:
